@@ -9,8 +9,8 @@ int main(int argc, char *argv[])
 {
 	KApplication app(argc, argv, "kbiff");
 	KBiff kbiff;
-	KBiffSetup* setup;
-	bool is_secure = false;
+	KBiffSetup* setup = 0;
+	bool is_secure    = false;
 	bool have_profile = false;
 	QString profile;
 
@@ -58,7 +58,10 @@ TRACEINIT("main()");
 		{
 			setup = new KBiffSetup();
 			if (!setup->exec())
+			{
+				delete setup;
 				return 0;
+			}
 		}
 		kbiff.processSetup(setup, true);
 	}
