@@ -103,8 +103,10 @@ KMComposeWin::KMComposeWin(KMMessage *aMsg) : KMComposeWinInherited(),
   mEdtFrom(this,&mMainWidget), mEdtReplyTo(this,&mMainWidget), 
   mEdtTo(this,&mMainWidget),  mEdtCc(this,&mMainWidget), 
   mEdtBcc(this,&mMainWidget), mEdtSubject(this,&mMainWidget, "subjectLine"),
-  mLblFrom(&mMainWidget), mLblReplyTo(&mMainWidget), mLblTo(&mMainWidget),
-  mLblCc(&mMainWidget), mLblBcc(&mMainWidget), mLblSubject(&mMainWidget),
+  mLblFrom(&mEdtFrom, "", &mMainWidget),
+  mLblReplyTo(&mEdtReplyTo, "", &mMainWidget), mLblTo(&mEdtTo, "", &mMainWidget),
+  mLblCc(&mEdtCc, "", &mMainWidget), mLblBcc(&mEdtBcc, "", &mMainWidget),
+  mLblSubject(&mEdtSubject, "", &mMainWidget),
   mBtnTo("...",&mMainWidget), mBtnCc("...",&mMainWidget), 
   mBtnBcc("...",&mMainWidget),  mBtnFrom("...",&mMainWidget),
   mBtnReplyTo("...",&mMainWidget)
@@ -186,7 +188,7 @@ KMComposeWin::KMComposeWin(KMMessage *aMsg) : KMComposeWinInherited(),
 //-----------------------------------------------------------------------------
 KMComposeWin::~KMComposeWin()
 {
-  debug("~KMComposeWin()");
+  //debug("~KMComposeWin()");
 
   writeConfig();
 
@@ -387,7 +389,7 @@ void KMComposeWin::rethinkHeaderLine(int aValue, int aMask, int& aRow,
     aLbl->resize((int)aLbl->sizeHint().width(),aLbl->sizeHint().height() + 6);
     aLbl->setMinimumSize(aLbl->size());
     aLbl->show();
-    aLbl->setBuddy(aEdt);
+    //aLbl->setBuddy(aEdt); //Discoverd by Don Sanders
     mGrid->addWidget(aLbl, aRow, 0);
 
     aEdt->show();
@@ -432,9 +434,11 @@ void KMComposeWin::setupMenuBar(void)
   menu->insertItem(i18n("&Send"),this, SLOT(slotSend()),
 		   CTRL+Key_Return);
   if (msgSender->sendImmediate())
-    menu->insertItem(i18n("S&end later"),this,SLOT(slotSendLater()));
+    menu->insertItem(i18n("S&end later"),this,SLOT(slotSendLater()),
+                    CTRL+SHIFT+Key_Return);
   else
-    menu->insertItem(i18n("S&end now"),this,SLOT(slotSendNow()));
+    menu->insertItem(i18n("S&end now"),this,SLOT(slotSendNow()),
+                    CTRL+SHIFT+Key_Return);
   menu->insertSeparator();
   menu->insertItem(i18n("&Insert File..."), this,
 		    SLOT(slotInsertFile()));
@@ -572,12 +576,11 @@ void KMComposeWin::setupToolBar(void)
 			SLOT(slotNewComposer()), TRUE, 
 			i18n("Compose new message"));
 
-#ifdef BROKEN
-  mToolBar->insertButton(loader->loadIcon("filefloppy.xpm"), 0, 
-			SIGNAL(clicked()), this,
-			SLOT(slotToDo()), TRUE,
-			i18n("Save message to file"));
-#endif
+  if (msgSender->sendImmediate())
+    mToolBar->insertButton(loader->loadIcon("filefloppy.xpm"), 0,
+                           SIGNAL(clicked()), this,
+                           SLOT(slotSendLater()), TRUE,
+                           i18n("send later")); //grr translations!!!
 
   mToolBar->insertButton(loader->loadIcon("fileprint.xpm"), 0, 
 			SIGNAL(clicked()), this,
@@ -1632,7 +1635,7 @@ void KMComposeWin::slotAppendSignature()
 
   if (!sigText.isEmpty())
   {
-    mEditor->insertLine("--", -1);
+    mEditor->insertLine("-- ", -1);
     mEditor->insertLine(sigText, -1);
     mEditor->toggleModified(mod);
   }
