@@ -53,7 +53,8 @@ KMFilterDlg::KMFilterDlg(QWidget* parent, const char* name):
   QGridLayout *fgrid, *grid, *agrid;
   int h, w, i;
   QSize sz;
-
+  updown_move_semaphore = 1;
+  
   initMetaObject();
 
   grid  = new QGridLayout(this, 4, 2, 4, 4);
@@ -232,9 +233,10 @@ void KMFilterDlg::clear(void)
 //-----------------------------------------------------------------------------
 void KMFilterDlg::showFilter(KMFilter* aFilter)
 {
-  int i;
+  int i, w;
   KMFilterAction* action;
   QWidget* pwidg;
+  QSize sz;
 
   assert(aFilter!=NULL); // Important assert
   clear();
@@ -279,6 +281,11 @@ void KMFilterDlg::showFilter(KMFilter* aFilter)
       {
 	QPoint pos = mFaType[i]->pos();
 	pos.setX(pos.x() + mFaType[i]->width() + 4);
+	w = width() - pos.x();
+	if (w > 300) w = 300;
+	sz.setWidth(w);
+	sz.setHeight(pwidg->height());
+	pwidg->resize(sz);
 	pwidg->move(pos);
 	pwidg->show();
       }
@@ -296,7 +303,7 @@ void KMFilterDlg::applyFilterChanges(void)
   KMFilterAction* action;
   int i;
 
-  if (!mFilter) return;
+  if (!mFilter || !updown_move_semaphore) return;
 
   mFilter->ruleA().init(mRuleFieldA->currentText(), 
 			(KMFilterRule::Function)mRuleFuncA->currentItem(),
@@ -342,6 +349,16 @@ QPushButton* KMFilterDlg::createDetailsButton(void)
 }
 
 
+//-----------------------------------------------------------------------------
+QLineEdit* KMFilterDlg::createEdit(const QString aTxt)
+{
+  QLineEdit* edt = new QLineEdit(this);
+
+  edt->setText(aTxt);
+  return edt;
+}
+
+
 //-----------------------------------------------------------------------------
 QComboBox* KMFilterDlg::createFolderCombo(const QString curFolder)
 {
@@ -410,18 +427,17 @@ void KMFilterDlg::slotActionTypeSelected(KMFaComboBox* cbx, int idx)
 //-----------------------------------------------------------------------------
 void KMFilterDlg::slotFilterSelected(int idx)
 {
-  KMFilter* filter;
 
   if (mFilter) applyFilterChanges();
   if ((uint)idx < filterMgr->count())
   {
-    filter = filterMgr->at(idx);
-    if (filter) showFilter(filter);
+    mFilter = filterMgr->at(idx);
+    if (mFilter) showFilter(mFilter);
   }
   else
   {
     clear();
-    mFilter = NULL;
+    mFilter = 0;
   }
 }
 
@@ -431,9 +447,11 @@ void KMFilterDlg::slotBtnUp()
 {
   int idx = mFilterList->currentItem();
   KMFilter* filter;
-
+  
   if (idx < 1) return;
 
+  updown_move_semaphore = 0;
+
   filter = filterMgr->take(idx);
   assert(filter != NULL);
   filterMgr->insert(idx-1, filter);
@@ -442,6 +460,8 @@ void KMFilterDlg::slotBtnUp()
   mFilterList->insertItem(filter->name(), idx-1);
 
   mFilterList->setCurrentItem(idx-1);
+
+  updown_move_semaphore = 1;
 }
 
 
@@ -453,6 +473,8 @@ void KMFilterDlg::slotBtnDown()
 
   if (idx < 0 || idx >= (int)mFilterList->count()-1) return;
 
+  updown_move_semaphore = 0;
+
   filter = filterMgr->take(idx);
   assert(filter != NULL);
   filterMgr->insert(idx+1, filter);
@@ -461,6 +483,8 @@ void KMFilterDlg::slotBtnDown()
   mFilterList->insertItem(filter->name(), idx+1);
 
   mFilterList->setCurrentItem(idx+1);
+
+  updown_move_semaphore = 1;
 }
 
 
@@ -478,6 +502,8 @@ void KMFilterDlg::slotBtnNew()
   mFilterList->insertItem(filter->name(), idx);
   mFilterList->setCurrentItem(idx);
   slotFilterSelected(idx);
+
+  mFilter=filter;
 }
 
 
@@ -488,21 +514,28 @@ void KMFilterDlg::slotBtnDelete()
   if (idx < 0) return;
 
   mFilter = 0;
+  //debug ("I zeroed filter, cross my heart!");
 
   mFilterList->removeItem(idx);
-  filterMgr->remove(idx);
+  filterMgr->remove(idx); //this is one true autoDelete
 
   if (idx >= (int)filterMgr->count())
     idx = (int)filterMgr->count()-1;
 
   if (idx >= 0) mFilterList->setCurrentItem(idx);
+  mFilter = filterMgr->at(idx);
+  if (mFilter) showFilter(mFilter);
 }
 
 
 //-----------------------------------------------------------------------------
 void KMFilterDlg::slotBtnOk()
 {
-  if (mFilter) applyFilterChanges();
+  if (mFilter) 
+  {
+    applyFilterChanges();
+    filterMgr->writeConfig();
+  }
   accept();
 }
 
@@ -510,6 +543,7 @@ void KMFilterDlg::slotBtnOk()
 //-----------------------------------------------------------------------------
 void KMFilterDlg::slotBtnCancel()
 {
+  filterMgr->readConfig();
   reject();
 }
 
@@ -517,6 +551,7 @@ void KMFilterDlg::slotBtnCancel()
 //-----------------------------------------------------------------------------
 void KMFilterDlg::slotBtnHelp()
 {
+  app->invokeHTMLHelp( app->appName() + "/" + "index-3.html", "ss3.5" );
 }
 
 
