@@ -75,6 +75,7 @@ KMFolder :: KMFolder(KMFolderDir* aParent, const char* aName) :
   mDirty          = FALSE;
   mWhoField       = 0;
   unreadMsgs      = -1;
+  needsCompact    = false;
 }
 
 
@@ -155,8 +156,8 @@ int KMFolder::open(void)
   }
   else
   {
-    debug("No path specified for folder `" + name() +
-	  "' -- Turning autoCreateIndex off");
+    //debug("No path specified for folder `" + name() +
+    //      "' -- Turning autoCreateIndex off");
     mAutoCreateIndex = FALSE;
     rc = createIndexFromContents();
   }
@@ -177,8 +178,10 @@ int KMFolder::create(void)
   assert(name() != "");
   assert(mOpenCount == 0);
 
+  if (access(location(), F_OK) == 0) return EEXIST;
+  
   old_umask = umask(077);
-  mStream = fopen(location(), "w");
+  mStream = fopen(location(), "w+"); //sven; open RW
   umask(old_umask);
 
   if (!mStream) return errno;
@@ -186,15 +189,15 @@ int KMFolder::create(void)
   if (!path().isEmpty())
   {
     old_umask = umask(077);
-    mIndexStream = fopen(indexLocation(), "w");
+    mIndexStream = fopen(indexLocation(), "w+"); //sven; open RW
     umask(old_umask);
 
     if (!mIndexStream) return errno;
   }
   else
   {
-    debug("Folder `" + name() +
-	  "' has no path specified -- turning autoCreateIndex off");
+    //debug("Folder `" + name() +
+    //      "' has no path specified -- turning autoCreateIndex off");
     mAutoCreateIndex = FALSE;
   }
 
@@ -565,6 +568,7 @@ void KMFolder::readIndex(void)
     {
       delete mi;  // skip messages that are marked as deleted
       mDirty = TRUE;
+      needsCompact = true;  //We have deleted messages - needs to be compacted
       continue;
     }
 #ifdef OBSOLETE
@@ -656,6 +660,7 @@ KMMessage* KMFolder::take(int idx)
   }
   msg->setParent(NULL);
   mDirty = TRUE;
+  needsCompact=true; // message is taken from here - needs to be compacted
   if (!mQuiet) emit msgRemoved(idx);
 
   return msg;
@@ -740,6 +745,7 @@ int KMFolder::addMsg(KMMessage* aMsg, int* aIndex_ret)
   char endStr[3];
   int idx, rc;
   KMFolder* msgParent;
+  bool editing = false;
 
   if (!mStream)
   {
@@ -753,7 +759,16 @@ int KMFolder::addMsg(KMMessage* aMsg, int* aIndex_ret)
   msgParent = aMsg->parent();
   if (msgParent)
   {
-    if (msgParent==this) return 0;
+    if (msgParent==this)
+    {
+      if (name() == "outbox") //special case for Edit message.
+      {
+        // debug ("Editing message in outbox");
+        editing = true;
+      }
+      else
+        return 0;
+    }
     idx = msgParent->find(aMsg);
     if (idx >= 0) msgParent->take(idx);
   }
@@ -870,6 +885,7 @@ int KMFolder::remove(void)
   if (rc) return rc;
 
   mMsgList.reset(INIT_MSGS);
+  needsCompact = false; //we are dead - no need to compact us
   return 0;
 }
 	
@@ -890,7 +906,8 @@ int KMFolder::expunge(void)
   mDirty = FALSE;
 
   mMsgList.reset(INIT_MSGS);
-
+  needsCompact = false; //we're cleared and truncated no need to compact
+  
   if (openCount > 0)
   {
     open();
@@ -913,13 +930,24 @@ int KMFolder::compact(void)
   int openCount = mOpenCount;
   int num, numStatus;
 
+
+  if (!needsCompact)
+  {
+    //debug ("Not compacting %s; it's clean", name().data());
+    return 0;
+  }
+  
+  debug ("Compacting %s ", name().data());
+  
   tempName = "." + name();
   tempName.detach();
   tempName += ".compacted";
   unlink(tempName);
-  tempFolder = parent()->createFolder(tempName);
-  if(!tempFolder) {
+  //tempFolder = parent()->createFolder(tempName); //sven: shouldn't be in list
+  tempFolder = new KMFolder(parent(), tempName);   //sven: we create it
+  if(tempFolder->create()) {
     debug("KMFolder::compact() Creating tempFolder failed!\n");
+    delete tempFolder;                             //sven: and we delete it
     return 0;
   }
 
@@ -949,7 +977,7 @@ int KMFolder::compact(void)
   _rename(tempFolder->indexLocation(), indexLocation());
 
   // Now really free all memory
-  parent()->remove(tempFolder);
+  delete tempFolder;                //sven: we delete it, not the manager
 
   if (openCount > 0)
   {
@@ -959,6 +987,7 @@ int KMFolder::compact(void)
   quiet(FALSE);
 
   if (!mQuiet) emit changed();
+  needsCompact = false;             // We are clean now
   return 0;
 }
 
@@ -996,9 +1025,9 @@ int KMFolder::sync(void)
 //-----------------------------------------------------------------------------
 void KMFolder::sort(KMMsgList::SortField aField, bool aDesc)
 {
-  debug("KMFolder::sort()");
+  //debug("KMFolder::sort()");
   mMsgList.sort(aField, aDesc);
-  debug("KMFolder::sort() after");
+  //debug("KMFolder::sort() after");
   if (!mQuiet) emit changed();
   mDirty = TRUE;
 }
@@ -1029,7 +1058,7 @@ const QString KMFolder::label(void) const
 //-----------------------------------------------------------------------------
 long KMFolder::countUnread(void)
 {
-  int  i;
+  register int  i;
 
   if (unreadMsgs != -1)
     return unreadMsgs;
