@@ -6,6 +6,7 @@
 #include "kmfolder.h"
 
 class KDNDDropZone;
+class QTimer;
 
 #define KMFolderTreeInherited KTabListBox
 class KMFolderTree : public KTabListBox
@@ -23,6 +24,7 @@ public:
 
 signals:
   void folderSelected(KMFolder*);
+  void msgMoved(KMFolder*, int);
 
 protected slots:
   void doFolderSelected(int,int);
@@ -34,9 +36,12 @@ protected slots:
   /** called when a drop occurs. */
   void doDropAction(KDNDDropZone*);
 
-  // Updates the folder tree only if some folder lable has changed
+  /** Updates the folder tree only if some folder lable has changed */
   void refresh(KMFolder*);
 
+  /** Executes delayed update of folder tree */
+  void delayedUpdate();
+
 protected:
   // Updates the number of unread messages for all folders
   virtual void KMFolderTree::updateUnreadAll( );
@@ -48,7 +53,7 @@ protected:
 
   KMFolderNodeList mList;
   KDNDDropZone* mDropZone;
+  QTimer* mUpdateTimer;
 };
 
 #endif
-
