@@ -22,6 +22,7 @@
 #include "kmfiltermgr.h"
 #include "kfontutils.h"
 
+#include "kmreaderwin.h"
 
 //-----------------------------------------------------------------------------
 KMHeaders::KMHeaders(KMMainWin *aOwner, QWidget *parent,
@@ -251,6 +252,8 @@ void KMHeaders::msgAdded(int id)
   if (!autoUpdate()) return;
   insertItem("", id);
   msgHeaderChanged(id);
+  if (mFolder->name() == "outbox")                            // special case ...
+    mOwner->messageView()->setMsg(mFolder->getMsg(id), true); // ... for Edited
 }
 
 
@@ -392,7 +395,8 @@ void KMHeaders::sortAndShow()
   if (idx >= 0) cur = (*mFolder)[idx];
   else cur = NULL;
 
-  sort();
+  if ((mSortCol != (int)KMMsgList::sfNone) || (mSortDescending != FALSE)) //Don
+    sort();
 
   if (cur) idx = mFolder->find(cur);
   else idx = 0;
@@ -582,10 +586,14 @@ void KMHeaders::moveMsgToFolder (KMFolder* destFolder, int msgId)
 
   for (rc=0, msg=msgList->first(); msg && !rc; msg=msgList->next())
   {
-    if (destFolder) rc = destFolder->moveMsg(msg);
+    if (destFolder) {
+      // "deleting" messages means moving them into the trash folder
+      rc = destFolder->moveMsg(msg);
+    }
     else
     {
-      if (!doUpd) removeItem(cur);
+      // really delete messages that are already in the trash folder
+      if (doUpd) removeItem(cur);
       mFolder->removeMsg(msg);
       delete msg;
     }
@@ -977,8 +985,14 @@ void KMHeaders::setPalette(const QPalette& p)
 void KMHeaders::slotRMB(int idx, int colId)
 {
   
-  highlightMessage(idx, colId);
-  setCurrentItem(idx);
+  //highlightMessage(idx, colId);
+  //setCurrentItem(idx);
+
+  if( ! isMarked(idx) ) {
+    highlightMessage(idx, colId);
+    setCurrentItem(idx);
+  }
+
 
   if (!topLevelWidget()) return; // safe bet
   
@@ -1016,6 +1030,17 @@ void KMHeaders::slotRMB(int idx, int colId)
   menu->exec (QCursor::pos(), 0);
   delete menu;
 }
-                        
+
+//-----------------------------------------------------------------------------
+
+void KMHeaders::removeItem(int itemIndex)
+{
+  KTabListBox::removeItem (itemIndex);
+  // If there's no messages left in the list then the reader window shouldn't
+  // be displaying any messages either!
+  if (count () < 1)
+    mOwner->messageView()->setMsg(0);
+}
+
 //-----------------------------------------------------------------------------
 #include "kmheaders.moc"
