@@ -21,6 +21,7 @@
 #include "kmsender.h"
 #include "kmaddrbookdlg.h"
 #include "kmaddrbook.h"
+#include "kwm.h"
 
 #include <qclipbrd.h>
 #include <qaccel.h>
@@ -83,7 +84,7 @@ KMMainWin::KMMainWin(QWidget *, char *name) :
 //-----------------------------------------------------------------------------
 KMMainWin::~KMMainWin()
 {
-  debug("~KMMainWin()");
+  //debug("~KMMainWin()");
 
   writeConfig();
 
@@ -232,7 +233,11 @@ void KMMainWin::createWidgets(void)
   connect(mMsgView, SIGNAL(popupMenu(const char*,const QPoint&)),
 	  this, SLOT(slotMsgPopup(const char*,const QPoint&)));
   connect(mMsgView, SIGNAL(urlClicked(const char*,int)),
-	  this, SLOT(slotUrlClicked(const char*,int)));
+          this, SLOT(slotUrlClicked(const char*,int)));
+
+  connect(mMsgView, SIGNAL(showAtmMsg(KMMessage *)),
+          this, SLOT(slotAtmMsg(KMMessage *)));
+
   accel->connectItem(accel->insertItem(Key_Up),
 		     mMsgView, SLOT(slotScrollUp()));
   accel->connectItem(accel->insertItem(Key_Down), 
@@ -248,6 +253,8 @@ void KMMainWin::createWidgets(void)
   mFolderTree  = new KMFolderTree(pnrFldList, "folderTree");
   connect(mFolderTree, SIGNAL(folderSelected(KMFolder*)),
 	  this, SLOT(folderSelected(KMFolder*)));
+	connect(mFolderTree, SIGNAL(msgMoved(KMFolder*,int)),
+	        mHeaders, SLOT(moveMsgToFolder(KMFolder*,int)));
 }
 
 
@@ -486,6 +493,10 @@ void KMMainWin::slotEmptyFolder()
   if (!mFolder) return;
 
   kbp->busy();
+
+  // begin of critical part
+  // from here to "end..." no signal may change to another mFolder, otherwise
+  // the wrong folder will be truncated in expunge (dnaber, 1999-08-29)
   mFolder->open();
   mHeaders->setFolder(NULL);
   mMsgView->clear();
@@ -494,10 +505,13 @@ void KMMainWin::slotEmptyFolder()
   {
     while ((msg = mFolder->take(0)) != NULL)
       trashFolder->addMsg(msg);
-    statusMsg(i18n("Moved all messages into trash"));
   }
   mFolder->close();
   mFolder->expunge();
+  // end of critical
+
+  if (mFolder != trashFolder)
+    statusMsg(i18n("Moved all messages into trash"));
   mHeaders->setFolder(mFolder);
   kbp->idle();
 }
@@ -510,7 +524,7 @@ void KMMainWin::slotRemoveFolder()
   QDir dir;
 
   if (!mFolder) return;
-  debug("TYPE: %s", (const char*)mFolder->type());
+  //debug("TYPE: %s", (const char*)mFolder->type());
   if (mFolder->isSystemFolder() || strcmp(mFolder->type(),"plain")!=0)
   {
     warning(i18n("Cannot remove a\nsystem folder."));
@@ -693,7 +707,6 @@ void KMMainWin::slotViewChange()
 //-----------------------------------------------------------------------------
 void KMMainWin::slotSetHeaderStyle(int id)
 {
-  if (!mMsgView) return;
   if(id <= 5)
   {
     mViewMenu->setItemChecked((int)mMsgView->headerStyle(), FALSE);
@@ -706,14 +719,17 @@ void KMMainWin::slotSetHeaderStyle(int id)
     mViewMenu->setItemChecked(id, TRUE);
     mMsgView->setAttachmentStyle(id-5);
   }
-  mMsgView->update(true);
+
+  // Can only update the message view if a message is displayed
+  //if(mHeaders->currentItem() >= 0)
+    mMsgView->update(true);
 }
 
 
 //-----------------------------------------------------------------------------
 void KMMainWin::folderSelected(KMFolder* aFolder)
 {
-  debug ("Entering folderSelected\n");
+  //debug ("Entering folderSelected\n");
   if(!aFolder)
     {
       debug("KMMainWin::folderSelected(): aFolder == NULL");
@@ -750,6 +766,7 @@ void KMMainWin::slotSetMsgStatus(int id)
 
 
 //-----------------------------------------------------------------------------
+//called from heders. Message must not be deleted on close
 void KMMainWin::slotMsgActivated(KMMessage *msg)
 {
   KMReaderWin *win;
@@ -757,9 +774,46 @@ void KMMainWin::slotMsgActivated(KMMessage *msg)
   assert(msg != NULL);
 
   win = new KMReaderWin;
+  showMsg(win, msg);
+}
+
+//called from reader win. message must be deleted on close
+void KMMainWin::slotAtmMsg(KMMessage *msg)
+{
+  KMReaderWin *win;
+
+  assert(msg != NULL);
+
+  win = new KMReaderWin;
+  win->setAutoDelete(true); //delete on end
+  showMsg(win, msg);
+}
+
+void KMMainWin::showMsg(KMReaderWin *win, KMMessage *msg)
+{
+  KWM::setMiniIcon(win->winId(), kapp->getMiniIcon());
   win->setCaption(msg->subject());
-  win->resize(550,600);
   win->setMsg(msg);
+  win->resize(550,600);
+  
+  connect(win, SIGNAL(statusMsg(const char*)),
+	  this, SLOT(statusMsg(const char*)));
+  connect(win, SIGNAL(popupMenu(const char*,const QPoint&)),
+	  this, SLOT(slotMsgPopup(const char*,const QPoint&)));
+  connect(win, SIGNAL(urlClicked(const char*,int)),
+          this, SLOT(slotUrlClicked(const char*,int)));
+
+  QAccel *accel = new QAccel(win);
+  
+  accel->connectItem(accel->insertItem(Key_Up),
+		     win, SLOT(slotScrollUp()));
+  accel->connectItem(accel->insertItem(Key_Down), 
+                     win, SLOT(slotScrollDown()));
+  accel->connectItem(accel->insertItem(Key_Prior),
+                     win, SLOT(slotScrollPrior()));
+  accel->connectItem(accel->insertItem(Key_Next), 
+                     win, SLOT(slotScrollNext()));
+  
   win->show();
 }
 
@@ -970,6 +1024,9 @@ void KMMainWin::setupMenuBar()
   fileMenu->insertItem(i18n("Print..."), this,
 		       SLOT(slotPrintMsg()), keys->print());
   fileMenu->insertSeparator();
+  fileMenu->insertItem(i18n("Compact all folders"), folderMgr,
+		       SLOT(compactAll()));
+  fileMenu->insertSeparator();
   fileMenu->insertItem(i18n("Check Mail..."), this,
 		       SLOT(slotCheckMail()), CTRL+Key_L);
   actMenu = new QPopupMenu();
@@ -1186,3 +1243,6 @@ void KMMainWin::quit()
   qApp->quit();
 }
 
+
+
+
