@@ -217,7 +217,7 @@ void KMMessage::setStatusFields(void)
 }
 
 //----------------------------------------------------------------------------
-const QString KMMessage::headerAsString(void)
+const QString KMMessage::headerAsString(void) const
 {
   DwHeaders& header = mMsg->Headers();
   if(header.AsString() != "")
@@ -362,7 +362,7 @@ const QString KMMessage::asQuotedString(const QString aHeaderStr,
 	if (stricmp(msgPart.typeStr(),"text")==0 || 
 	    stricmp(msgPart.typeStr(),"message")==0)
 	{
-	  result += aIndentStr;
+	  result += nlIndentStr;
           Kpgp* pgp = Kpgp::getKpgp();
           assert(pgp != NULL);
 	  QString part;
@@ -406,18 +406,18 @@ const QString KMMessage::asQuotedString(const QString aHeaderStr,
 KMMessage* KMMessage::createReply(bool replyToAll)
 {
   KMMessage* msg = new KMMessage;
-  QString str, replyStr, loopToStr, replyToStr, toStr;
+  QString str, replyStr, mailingListStr, replyToStr, toStr, refStr;
 
   msg->initHeader();
 
-  loopToStr = headerField("X-Loop");
+  mailingListStr = headerField("X-Mailing-List");
   replyToStr = replyTo();
 
   if (replyToAll)
   {
     int i;
     if (!replyToStr.isEmpty()) toStr += replyToStr + ", ";
-    else if (!loopToStr.isEmpty()) toStr = loopToStr + ", ";
+    // else if (!loopToStr.isEmpty()) toStr = loopToStr + ", "; //no to loop
     if (!from().isEmpty()) toStr += from() + ", ";
     if (!to().isEmpty()) toStr += to() + ", ";
     toStr = toStr.simplifyWhiteSpace() + " ";
@@ -443,27 +443,54 @@ KMMessage* KMMessage::createReply(bool replyToAll)
       pos1 = ccStr.findRev(", ", i);
       if( pos1 == -1 ) pos1 = 0;
       pos2 = ccStr.find(", ", i);
-      ccStr = ccStr.left(pos1) + toStr.right(toStr.size() - pos2 - 1);
+      ccStr = ccStr.left(pos1) + ccStr.right(ccStr.size() - pos2 - 1); //Daniel
     }
     ccStr.truncate(ccStr.length()-2);
-    msg->setCc(ccStr);
+
+    // remove leading or trailing "," and spaces - might confuse some MTAs
+    if (!ccStr.isEmpty())
+    {
+      ccStr = ccStr.stripWhiteSpace(); //from start and end
+      if (ccStr[0] == ',')  ccStr[0] = ' ';
+      ccStr = ccStr.simplifyWhiteSpace(); //mAybe it was ",  "
+      if (ccStr[ccStr.length()-1] == ',')
+        ccStr.truncate(ccStr.length()-1);
+      msg->setCc(ccStr);
+    }
+    
   }
   else
   {
     if (!replyToStr.isEmpty()) toStr = replyToStr;
-    else if (!loopToStr.isEmpty()) toStr = loopToStr;
+    // else if (!loopToStr.isEmpty()) toStr = loopToStr; //no sending to loop
     else if (!from().isEmpty()) toStr = from();
   }
 
-  if (!toStr.isEmpty()) msg->setTo(toStr);
+  
+  // remove leading or trailing "," and spaces - might confuse some MTAs
+  if (!toStr.isEmpty())
+  {
+    toStr = toStr.stripWhiteSpace(); //from start and end
+    if (toStr[0] == ',')  toStr[0] = ' ';
+    toStr = toStr.simplifyWhiteSpace(); //maybe it was ",  "
+    if (toStr[toStr.length()-1] == ',')
+      toStr.truncate(toStr.length()-1);
+    msg->setTo(toStr);
+  }
 
-  if (replyToAll || !loopToStr.isEmpty()) replyStr = sReplyAllStr;
+  refStr = getRefStr();
+
+  if (!refStr.isEmpty())
+    msg->setReferences(refStr);
+
+  //In-Reply-To = original msg-id
+  msg->setHeaderField("In-Reply-To", headerField("Message-Id"));
+
+  if (replyToAll || !mailingListStr.isEmpty()) replyStr = sReplyAllStr;
   else replyStr = sReplyStr;
 
-  debug("msg-id: %s", headerField("Message-Id").data());
-  msg->setReferences(headerField("Message-Id"));
   msg->setBody(asQuotedString(replyStr, sIndentPrefixStr));
-
+  
   if (strnicmp(subject(), "Re:", 3)!=0)
     msg->setSubject("Re: " + subject());
   else msg->setSubject(subject());
@@ -477,6 +504,44 @@ KMMessage* KMMessage::createReply(bool replyToAll)
 }
 
 
+//-----------------------------------------------------------------------------
+const QString KMMessage::getRefStr()
+{
+  QString firstRef, lastRef, refStr, retRefStr;
+  int i, j;
+
+  refStr = headerField("References").stripWhiteSpace ();
+  debug("References = %s", refStr.data());
+  if (refStr.isEmpty())
+  {
+    //debug ("New references: %s", headerField("Message-Id").data());
+    return headerField("Message-Id");
+  }
+
+  i = refStr.find("<");
+  j = refStr.find(">");
+  firstRef = refStr.mid(i, j-i+1);
+  if (!firstRef.isEmpty())
+    retRefStr = firstRef + " ";
+
+  //debug ("firstRef = \"%s\"",  firstRef.data());
+
+  i = refStr.findRev("<");
+  j = refStr.findRev(">");
+
+  lastRef = refStr.mid(i, j-i+1);
+  if (!lastRef.isEmpty() && lastRef != firstRef)
+    retRefStr += lastRef + " ";
+
+  //debug ("lastRef  = \"%s\"", lastRef.data());
+
+  retRefStr += headerField("Message-Id");
+
+  //debug("New references = %s", retRefStr.data());
+  return retRefStr;
+}
+
+
 //-----------------------------------------------------------------------------
 KMMessage* KMMessage::createForward(void)
 {
@@ -493,7 +558,7 @@ KMMessage* KMMessage::createForward(void)
   str += "From: " + from() + "\n";
   str += "\n";
   str = asQuotedString(str, "", FALSE);
-
+  str += "\n-------------------------------------------------------\n";
   if (numBodyParts() <= 0)
   {
     msg->setBody(str);
