@@ -113,7 +113,7 @@ public:
    * (e.g. ':' or ',') and skip the then following blanks (if any) too.
    * If keywordFound is specified it will be TRUE if a keyword was skipped
    * and FALSE otherwise. */
-  static const char* skipKeyword(const QString str, char sepChar=':',
+  static QString skipKeyword(const QString str, char sepChar=':',
 				 bool* keywordFound=NULL);
 
   /** Copy all values from other to this object. */
