@@ -387,9 +387,12 @@ void KMSettings::createTabComposer(QWidget *parent)
   box->addWidget(grp);
   grid = new QGridLayout(grp, 7, 3, 20, 4);
 
-  lbl = new QLabel(i18n(
+  QString t = i18n(
         "The following placeholders are supported in the reply phrases:\n"
-	"%D=date, %S=subject, %F=sender, %%=percent sign"), grp);
+        "%D=date, %S=subject, %F=sender, %%=percent sign");
+
+  t.append (i18n(", %_=space"));
+  lbl = new QLabel(t.data(), grp);
   lbl->adjustSize();
   lbl->setMinimumSize(100,lbl->size().height());
   grid->setRowStretch(0,10);
@@ -537,7 +540,7 @@ void KMSettings::createTabMisc(QWidget *parent)
   //---------- group: folders
   grp = new QGroupBox(i18n("Folders"), tab);
   box->addWidget(grp);
-  grid = new QGridLayout(grp, 2, 3, 20, 4);
+  grid = new QGridLayout(grp, 4, 4, 20, 4);
 
   emptyTrashOnExit=new QCheckBox(i18n("empty trash on exit"),grp);
   emptyTrashOnExit->setMinimumSize(emptyTrashOnExit->sizeHint());
@@ -545,14 +548,24 @@ void KMSettings::createTabMisc(QWidget *parent)
 
   sendOnCheck = new QCheckBox(i18n("Send Mail in outbox Folder on Check"),grp);
   sendOnCheck->setMinimumSize(sendOnCheck->sizeHint());
-  grid->addMultiCellWidget(sendOnCheck,1,1,0,2);
+  grid->addMultiCellWidget(sendOnCheck, 1, 1, 0, 2);
 
+  sendReceipts = new QCheckBox(i18n("Automatically send receive- and read confirmations"),grp);
+  sendReceipts->setMinimumSize(sendReceipts->sizeHint());
+  grid->addMultiCellWidget(sendReceipts, 2, 2, 0, 2);
+
+  compactOnExit = new QCheckBox(i18n("Compact all folders on exit"),grp);
+  compactOnExit->setMinimumSize(compactOnExit->sizeHint());
+  grid->addMultiCellWidget(compactOnExit, 3, 3, 0, 2);
+  
   grid->activate();
 
   //---------- set values
   config->setGroup("General");
-  emptyTrashOnExit->setChecked(config->readNumEntry("empty-trash-on-exit",0));
-  sendOnCheck->setChecked(config->readBoolEntry("sendOnCheck",false));
+  emptyTrashOnExit->setChecked(config->readNumEntry("empty-trash-on-exit", 0));
+  compactOnExit->setChecked(config->readNumEntry("compact-all-on-exit", 0));
+  sendOnCheck->setChecked(config->readBoolEntry("sendOnCheck", false));
+  sendReceipts->setChecked(config->readBoolEntry("send-receipts", true));
 
   //---------- here we go
   box->addStretch(10);
@@ -830,8 +843,10 @@ void KMSettings::doApply()
   //----- misc
   config->setGroup("General");
   config->writeEntry("empty-trash-on-exit", emptyTrashOnExit->isChecked());
+  config->writeEntry("compact-all-on-exit", compactOnExit->isChecked());
   config->writeEntry("first-start", FALSE);
-  config->writeEntry("sendOnCheck",sendOnCheck->isChecked());
+  config->writeEntry("sendOnCheck", sendOnCheck->isChecked());
+  config->writeEntry("send-receipts", sendReceipts->isChecked());
 
   //-----
   config->sync();
