@@ -583,6 +583,13 @@ KpgpBase5::encsign(const QStrList *_recipients, const char *passphrase,
       cmd += " +EncryptToSelf";
   }
 
+  if (signonly)
+  {
+    input.append("\n");
+    input.replace(QRegExp("[ \t]+\n"), "\n");   //strip trailing whitespace
+  }
+  //We have to do this otherwise it's all in vain
+  
   status = run(cmd, passphrase);
   if(status == RUN_ERR) return status;
   
@@ -636,9 +643,8 @@ KpgpBase5::encsign(const QStrList *_recipients, const char *passphrase,
     status |= MISSINGKEY;
   }
   
-  if(signonly)
+  if (signonly)
     output = "-----BEGIN PGP SIGNED MESSAGE-----\n\n" + input + "\n" + output;
-
   return status;
 }
 
