@@ -18,6 +18,7 @@
 #include "kmaddrbook.h"
 #include "kcharsets.h"
 #include "kmsettings.h"
+#include "kmreaderwin.h"
 
 #include <kapp.h>
 #include <stdio.h>
@@ -116,7 +117,8 @@ static void kmailMsgHandler(QtMsgType aType, const char* aMsg)
 	strncmp(aMsg,"QGManager:",10) != 0 &&
 	strncmp(aMsg,"QPainter:",9) != 0 &&
 	strncmp(aMsg,"Could not load", 14) != 0 &&
-	strncmp(aMsg,"QPixmap:",8) != 0)
+	strncmp(aMsg,"QPixmap:",8) != 0 &&
+	strncmp(aMsg,"ASSERT:", 7 ) != 0 )
     {
       KMsgBox::message(NULL, appName+" "+i18n("warning"), msg.data(),
 		       KMsgBox::EXCLAMATION);
@@ -144,6 +146,7 @@ static void writePid (bool ready)
   FILE* lck;
   char nlck[80];
   sprintf (nlck, "%s.kmail%d.lck", _PATH_TMP, getuid());
+  unlink (nlck); // Security - in case it was a socket, link, device...
   lck = fopen (nlck, "w");
   if (!ready)
     fprintf (lck, "%d", 0-getpid());
@@ -158,7 +161,7 @@ static void checkMessage()
   sprintf (lf, "%s.kmail%d.msg", _PATH_TMP, getuid());
   if (access(lf, F_OK) != 0)
   {
-    debug ("No message for me");
+    //debug ("No message for me");
     return;
   }
   QString cmd;
@@ -182,17 +185,18 @@ static void checkMessage()
     }
     else
       KWM::activate(kmmWin->winId());
-    //kmmWin->show();
-    //kmmWin->raise();
   }
   else if (cmd.find ("check") == 0)
   {
     //printf ("check();\n");
     if (!kmmWin)
+    {
       kmmWin = new KMMainWin;
-    KWM::activate(kmmWin->winId());
-    //kmmWin->show();
-    //kmmWin->raise();
+      kmmWin->show(); // thanks, jbb!
+    }
+    else
+      KWM::activate(kmmWin->winId());
+
     kmmWin->slotCheckMail();
   }
   else
@@ -500,6 +504,11 @@ static void cleanup(void)
   KConfig* config =  kapp->getConfig();
   shuttingDown = TRUE;
 
+  // Hm. When I think again, the whole cleanup lasts too long. Destructing
+  // and config may take some time, so we better mark us as busy
+  // on the beginning of cleanup.
+  serverReady(false);      // Knock again, but you won't come in!
+
   if (trashFolder)
   {
     trashFolder->close(TRUE);
@@ -507,6 +516,12 @@ static void cleanup(void)
     if (config->readNumEntry("empty-trash-on-exit", 0))
       trashFolder->expunge();
   }
+  if (folderMgr)
+  {
+    if (config->readNumEntry("compact-all-on-exit", 0))
+      folderMgr->compactAll(); // I can compact for ages in peace now!
+  }
+    
   if (inboxFolder) inboxFolder->close(TRUE);
   if (outboxFolder) outboxFolder->close(TRUE);
   if (sentFolder) sentFolder->close(TRUE);
@@ -525,14 +540,22 @@ static void cleanup(void)
   QString cmd;
   // This is a dir with attachments and it is not critical if they are
   // left behind.
-  cmd.sprintf("rm -rf %skmail%d", _PATH_TMP, getpid());
-  system (cmd.data()); // delete your owns only
+  if (!KMReaderWin::attachDir().isEmpty())
+  {
+    cmd.sprintf("rm -rf '%s'", (const char*)KMReaderWin::attachDir());
+    system (cmd.data()); // delete your owns only
+  }
   //--- Sven's save attachments to /tmp end ---
   //--- Sven's pseudo IPC&locking start ---
   cmd.sprintf("%s.kmail%d.lck", _PATH_TMP, getuid());
   unlink(cmd.data()); // delete your owns only
   cmd.sprintf("%s.kmail%d.msg", _PATH_TMP, getuid());
   unlink(cmd.data()); // delete your owns only
+  // Compacting all and whole cleanup () may take some time;
+  // What if message about new kmail comes in the meantime?
+  // We're marked as busy and client might leave the message, but we
+  // didn't answer; we are beyond all destructors and can't wake any more.
+  // What to do? Ignore? Let's ignore. He can press that button again!
   //--- Sven's pseudo IPC&locking end ---
 }
 
@@ -667,6 +690,12 @@ static void processArgs(int argc, char *argv[])
 }
 */
 
+void version() {
+
+ printf("%s\n",aboutText);
+
+}
+
 //-----------------------------------------------------------------------------
 main(int argc, char *argv[])
 {
@@ -696,6 +725,7 @@ main(int argc, char *argv[])
         exit (0);
       }
       sprintf (lf, "%s.kmail%d.msg", _PATH_TMP, getuid());
+      unlink (lf); // In case of socket, link...
       msg = fopen (lf, "w");
       int i;
       app = new KApplication(argc, argv, "kmail"); // clear arg list
@@ -712,6 +742,11 @@ main(int argc, char *argv[])
           if (i<argc-1) subj = argv[++i];
           mailto = TRUE;
         }
+	else if (strcmp(argv[i],"-v")==0)
+	{
+	  version();
+ 	  exit(0);
+	}
         else if (strcmp(argv[i],"-c")==0)
         {
           if (i<argc-1) cc = argv[++i];
@@ -757,11 +792,11 @@ main(int argc, char *argv[])
         if (kill(0-pId, 0) != 0)      // try if it lives at all
         {
           debug ("Server died whyle busy");
-          writePid(true);             // he diedd and left his pid uncleaned
+          writePid(true);             // he died and left his pid uncleaned
         }
         else
         {
-          debug ("Server is busy - message pending");
+          //debug ("Server is busy - message pending");
           exit (0);                   // ok he lives but is busy
         }
       }
@@ -774,12 +809,12 @@ main(int argc, char *argv[])
         }
         else
         {
-          debug ("Server is ready - message sent");
+          //debug ("Server is ready - message sent");
           exit (0);
         }
       }
     }
-    debug ("We are starting normaly");
+    //debug ("We are starting normaly");
     sprintf(lf, "%s.kmail%d.msg", _PATH_TMP, getuid());
     unlink(lf); // clear old mesage
   }
