@@ -1,7 +1,7 @@
 /*
  *            kPPP: A pppd front end for the KDE project
  *
- * $Id: connect.cpp,v 1.98.2.5 1999/04/10 16:11:18 porten Exp $
+ * $Id: connect.cpp,v 1.98.2.10 1999/08/08 15:07:55 porten Exp $
  * 
  *            Copyright (C) 1997 Bernd Johannes Wuebben 
  *                   wuebben@math.cornell.edu
@@ -813,11 +813,16 @@ void ConnectWidget::readChar(unsigned char c) {
     // add to debug window
     emit debugPutChar(c);
 
+    checkBuffers();
+}
 
+
+void ConnectWidget::checkBuffers() {
   // Let's check if we are finished with scanning:
   // The scanstring have to be in the buffer and the latest character
   // was a carriage return or an linefeed (depending on modem setup)
-  if( scanning && scanbuffer.contains(scanstr) && (c == '\n' || c == '\r') ) {
+  if( scanning && scanbuffer.contains(scanstr) &&
+      ( scanbuffer.right(1) == "\n" || scanbuffer.right(1) == "\r") ) {
       scanning = false;
 
       int vstart = scanbuffer.find( scanstr ) + scanstr.length();
@@ -956,7 +961,11 @@ void ConnectWidget::setExpect(const char *n) {
 
   QString ts = i18n("Expecting: ");
   ts += n;
+  ts.replace(QRegExp("\n"), "<LF>");
   emit debugMessage(ts);
+
+  // check if the expected string is in the read buffer already.
+  checkBuffers();
 }
 
 
