@@ -1,7 +1,7 @@
 /*
  *            kPPP: A pppd front end for the KDE project
  *
- * $Id: main.cpp,v 1.115.2.4 1999/04/06 10:57:55 porten Exp $
+ * $Id: main.cpp,v 1.115.2.6 1999/08/26 16:13:24 porten Exp $
  * 
  *            Copyright (C) 1997 Bernd Johannes Wuebben 
  *                   wuebben@math.cornell.edu
@@ -536,8 +536,7 @@ KPPPWidget::KPPPWidget( QWidget *parent, const char *name )
   MIN_SIZE(PW_Label);
   l1->addWidget(PW_Label, 2, 1);
 
-  PW_Edit= new QLineEdit(this);
-  PW_Edit->setEchoMode(QLineEdit::Password);
+  PW_Edit= new PasswordWidget(this);
   MIN_WIDTH(PW_Edit);
   FIXED_HEIGHT(PW_Edit);
   l1->addWidget(PW_Edit, 2, 2);
@@ -878,7 +877,7 @@ void dieppp(int) {
 	
 	KMsgBox msgb(0, 
 		     i18n("Error"), 
-		     i18n(msg),
+		     msg,
 		     KMsgBox::STOP | KMsgBox::DB_FIRST,
 		     i18n("OK"),
 		     i18n("Details..."));
@@ -1228,6 +1227,17 @@ void KPPPWidget::resetCosts(const char *s) {
   AccountingBase::resetCosts(s);
 }
 
+PasswordWidget::PasswordWidget(QWidget *parent, const char *name)
+  : QLineEdit(parent, name)
+{
+  setEchoMode(Password);
+}
+
+void PasswordWidget::focusOutEvent(QFocusEvent *e)
+{
+  deselect();
+  QLineEdit::focusOutEvent(e);
+}
 
 pid_t execute_command (const char *command) {
     if(!command || strcmp(command, "") ==0 || strlen(command) > COMMAND_SIZE)
