@@ -1,7 +1,7 @@
 /*
  *            kPPP: A pppd front end for the KDE project
  *
- * $Id: pppdata.cpp,v 1.53.2.4 1999/04/10 16:11:20 porten Exp $
+ * $Id: pppdata.cpp,v 1.53.2.7 1999/08/17 16:26:54 porten Exp $
  * 
  *            Copyright (C) 1997 Bernd Johannes Wuebben 
  *                   wuebben@math.cornell.edu
@@ -335,7 +335,13 @@ void PPPData::setFlowcontrol(const char *n) {
 
 
 const char* PPPData::speed() {
-  return readConfig(MODEM_GRP, SPEED_KEY);
+  const char* s = readConfig(MODEM_GRP, SPEED_KEY, "57600");
+  // undo the damage of a bug in former versions. It left an empty Speed=
+  // entry in kppprc. kppp did set the serial port to 57600 as default but
+  // pppd wouldn't receive the speed via the command line.
+  if(!s || atoi(s) == 0)
+    s = "57600";
+  return s;
 }
 
 
@@ -343,7 +349,7 @@ void PPPData::setSpeed( const char *n ) {
   writeConfig(MODEM_GRP, SPEED_KEY, n);
 }
 
-
+#if 0
 void PPPData::setUseCDLine(const int n) {
   writeConfig(MODEM_GRP,USECDLINE_KEY,n);
 }
@@ -352,7 +358,7 @@ void PPPData::setUseCDLine(const int n) {
 int PPPData::UseCDLine() {
   return  readNumConfig(MODEM_GRP,USECDLINE_KEY,0);
 }
-
+#endif
 
 const char*  PPPData::modemEscapeStr() {
   return readConfig(MODEM_GRP,ESCAPESTR_KEY,"+++");
@@ -617,7 +623,7 @@ void PPPData::setModemAnswerResp(const char *n) {
 
 
 const char* PPPData::enter() {
-  return readConfig(MODEM_GRP, ENTER_KEY, "CR/LF");
+  return readConfig(MODEM_GRP, ENTER_KEY, "CR");
 }
 
 
